/**
 * Created by John on 7/3/2017.
 */
var AsnHelper = require("../components/helpers/AsnHelper");
var path = require("path");
var env         = process.env.NODE_ENV || "prod";
var config      = require(path.join(__dirname,  '..', '/components/config/server.' + env + '.js'))['db'];

module.exports = function(app) {

    var models = app.get('models');
    var winston = app.get('winston');
    var logger = winston.loggers.get('main');

    app.get("/api/healthcheck", function(req, res){
        res.status(200).send("OK");
    });

    app.get('/api/v1/asn', function(req,res){
        var helper = new AsnHelper(models, winston);
        helper.getAllASNs(req).then(function(result){
            res.header("X-Total-Count", result.count)
            res.status(200).send(result.rows);
        }).catch(function(err){
            console.error(err);
            res.status(500).send(JSON.stringify(err));
        });

    });

    app.get('/api/v1/asn/open', function(req,res){
        var helper = new AsnHelper(models, winston);
        helper.getOpenAsns(req).then(function(result){
            res.header("X-Total-Count", result.count)
            res.status(200).send(result.rows);
        }).catch(function(err){
            res.status(500).send(JSON.stringify(err));
        });

    });

    app.get('/api/v1/asn/clinic/:clinic', function(req,res){
        if (!req.params.clinic) {
            res.status(400).send("Invalid Clinic ID!");
        } else {
            var helper = new AsnHelper(models, winston);
            helper.getAllASNsForClinic(req).then(function (data) {
                res.status(200).send(data);
            }).catch(function (err) {
                res.status(500).send(err);
            });
        }
    });

    app.post('/api/v1/asn', function(req, res) {
        var asns = req.body;
        var helper = new AsnHelper(models, winston);
        if (Array.isArray(asns)) {
            var promises = helper.saveAsns(asns);
            Promise.all(promises).then(function(data){
                res.status(200).send(data);
            }).catch(function(err) {
                logger.error(err);
                res.status(500).send(JSON.stringify(err));
            });
        } else {
            helper.saveAsn(asns).then(function (data) {
                res.status(200).send(data);
            }).catch(function(err) {
                logger.error(err);
                res.status(500).send(JSON.stringify(err));
            });
        }
    });

    /**
     * TODO: Remove or fix.  Replaced with a trigger/hook for more accurate incrementing of received qty.
     */
    app.patch('/api/v1/asn/:id', function(req,res){
        if (config.dialect === "mssql") {
            if (req.params['id']) {
                models.sequelize
                    .query('EXEC [db_owner].[prc_update_asn] :asnId',
                        {replacements: {asnId: req.params['id']}})
                    .then(function (v) {
                        res.status(200).send(v);
                    })
                    .catch(function (err) {
                        res.status(500).send(err);
                    });
            } else {
                res.status(400).send("Missing parameter");
            }
        } else {
            res.status(404).send("Deprecated");
        }
    });



};